@@ -24,7 +24,8 @@
 #' @param x_zero For a numeric x variable, TRUE or FALSE of whether the minimum of the x scale is zero. Defaults to FALSE.
 #' @param x_zero_line For a numeric x variable, TRUE or FALSE of whether to add a zero reference line to the x scale. Defaults to TRUE if there are positive and negative values in x_var. Otherwise defaults to FALSE.   
 #' @param y_balance For a numeric y variable, add balance to the y scale so that zero is in the centre of the y scale.
-#' @param y_expand A vector of range expansion constants used to add padding to the y scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
+#' @param y_expand A vector of range expansion constants used to add padding to the y scale, as per the ggplot2 expand argument in ggplot2 scales functions.
+#' @param y_gridlines_minor TRUE or FALSE of whether to add minor gridlines to the y scale. Defaults to FALSE.
 #' @param y_labels A function or vector to modify y scale labels, as per the ggplot2 labels argument in ggplot2 scales functions. If NULL, categorical variable labels are converted to sentence case. Use ggplot2::waiver() to keep y labels untransformed.
 #' @param y_na TRUE or FALSE of whether to include y_var NA values. Defaults to TRUE.
 #' @param y_pretty_n For a numeric or date y variable, the desired number of intervals on the y scale, as calculated by the pretty algorithm. Defaults to 5. 
@@ -50,7 +51,9 @@
 #'   group_by(species) %>% 
 #'   summarise(body_mass_g = mean(body_mass_g, na.rm = TRUE))  
 #' 
-#' gg_bar(plot_data, species, body_mass_g)
+#' gg_bar(plot_data, 
+#'        x_var = species, 
+#'        y_var = body_mass_g)
 #' 
 gg_bar <- function(data,
                     x_var,
@@ -77,6 +80,7 @@ gg_bar <- function(data,
                     x_zero_line = NULL,
                     y_balance = FALSE,
                     y_expand = NULL,
+                    y_gridlines_minor = FALSE,
                     y_labels = waiver(),
                     y_na = TRUE,
                     y_pretty_n = 5,
@@ -154,7 +158,7 @@ gg_bar <- function(data,
   bar_width <- bar_unit * width
   
   plot <- ggplot(data) +
-    theme_bar(font_family = font_family, font_size_body = font_size_body, font_size_title = font_size_title) +
+    theme_y_gridlines(font_family = font_family, font_size_body = font_size_body, font_size_title = font_size_title) +
     geom_col(aes(x = !!x_var, y = !!y_var, text = !!text_var), 
              col = pal, 
              fill = pal, 
@@ -245,6 +249,11 @@ gg_bar <- function(data,
       geom_hline(yintercept = 0, colour = "#323232", size = 0.3)
   }
   
+  if (y_gridlines_minor == TRUE) {
+    plot <- plot +
+      theme(panel.grid.minor.y = element_line(colour = "#D3D3D3", size = 0.2))
+  }
+
   if (mobile == FALSE) {
     plot <- plot +
       labs(
@@ -264,7 +273,7 @@ gg_bar <- function(data,
         y = stringr::str_wrap(y_title, 30),
         caption = stringr::str_wrap(caption, 50)
       ) +
-      theme_mobile_graph()
+      theme_mobile_extra()
   }
   
   return(plot)
@@ -299,6 +308,7 @@ gg_bar <- function(data,
 #' @param x_zero_line For a numeric x variable, TRUE or FALSE of whether to add a zero reference line to the x scale. Defaults to TRUE if there are positive and negative values in x_var. Otherwise defaults to FALSE.   
 #' @param y_balance For a numeric y variable, add balance to the y scale so that zero is in the centre of the y scale.
 #' @param y_expand A vector of range expansion constants used to add padding to the y scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
+#' @param y_gridlines_minor TRUE or FALSE of whether to add minor gridlines to the y scale. Defaults to FALSE.
 #' @param y_labels A function or vector to modify y scale labels, as per the ggplot2 labels argument in ggplot2 scales functions. If NULL, categorical variable labels are converted to sentence case. Use ggplot2::waiver() to keep y labels untransformed.
 #' @param y_na TRUE or FALSE of whether to include y_var NA values. Defaults to TRUE.
 #' @param y_pretty_n For a numeric or date y variable, the desired number of intervals on the y scale, as calculated by the pretty algorithm. Defaults to 5. 
@@ -331,16 +341,23 @@ gg_bar <- function(data,
 #'   group_by(species, sex) %>% 
 #'   summarise(body_mass_g = mean(body_mass_g, na.rm = TRUE))  
 #' 
-#' gg_bar_col(plot_data, species, body_mass_g, sex)
+#' gg_bar_col(plot_data, 
+#'            x_var = species, 
+#'            y_var = body_mass_g, 
+#'            col_var = sex)
 #' 
-#' gg_bar_col(plot_data, species, body_mass_g, sex, position = "stack")
+#'  gg_bar_col(plot_data, 
+#'            x_var = species, 
+#'            y_var = body_mass_g, 
+#'            col_var = sex,
+#'            position = "stack")
 #' 
 gg_bar_col <- function(data,
                         x_var,
                         y_var,
                         col_var,
                         text_var = NULL,
-                        position = "dodge",
+                        position = NULL,
                         pal = NULL,
                         pal_rev = FALSE,
                         width = 0.75,
@@ -362,6 +379,7 @@ gg_bar_col <- function(data,
                         x_zero_line = NULL,
                         y_balance = FALSE,
                         y_expand = NULL,
+                        y_gridlines_minor = FALSE,
                         y_labels = waiver(),
                         y_na = TRUE,
                         y_pretty_n = 5,
@@ -411,13 +429,6 @@ gg_bar_col <- function(data,
   if (!is.numeric(y_var_vctr)) stop("Please use a numeric y variable for a vertical bar plot")
   if (is.numeric(col_var_vctr)) stop("Please use a categorical colour variable for a vertical bar plot")
   
-  if (y_trans != "identity") {
-    if (position == "stack") stop("Please use position = 'dodge', if you would like to not have zero as the minimum of y scale")
-  } 
-  if (y_zero == FALSE) {
-    if (position == "stack") stop("Please use position = 'dodge', if you would like to not have zero as the minimum of y scale")
-  }
-  
   if(is.logical(x_var_vctr)) {
     data <- data %>% 
       dplyr::mutate(dplyr::across(!!x_var, ~factor(., levels = c("TRUE", "FALSE"))))
@@ -459,9 +470,6 @@ gg_bar_col <- function(data,
   if(is.null(font_size_title)) font_size_title <- sv_font_size_title(mobile = mobile)
   if(is.null(font_size_body)) font_size_body <- sv_font_size_body(mobile = mobile)
   
-  if (position == "stack") position2 <- "stack"
-  else if (position == "dodge") position2 <- position_dodge2(preserve = "single")
-  
   if (lubridate::is.Date(x_var_vctr)) bar_unit <- 365
   else bar_unit <- 1
   
@@ -477,8 +485,17 @@ gg_bar_col <- function(data,
   
   if (pal_rev == TRUE) pal <- rev(pal)
   
+  if(!is.null(position)) {
+    if (!position %in% c("dodge", "stack")) stop("Please use a position of either 'stack' or 'fill'")
+  }
+  
+  if (is.null(position)) {
+    position2 <- position_dodge2(preserve = "single")
+  }
+  else position2 <- position
+  
   plot <- ggplot(data) +
-    theme_bar(font_family = font_family, font_size_body = font_size_body, font_size_title = font_size_title) +
+    theme_y_gridlines(font_family = font_family, font_size_body = font_size_body, font_size_title = font_size_title) +
     geom_col(aes(x = !!x_var, y = !!y_var, col = !!col_var, fill = !!col_var, text = !!text_var), 
              alpha = alpha, 
              size = size_line, 
@@ -538,13 +555,16 @@ gg_bar_col <- function(data,
       scale_x_discrete(expand = x_expand, labels = x_labels)
   } 
   
-  if (position == "stack") {
-    data_sum <- data %>%
-      dplyr::group_by(dplyr::across(!!x_var), .drop = FALSE) %>%
-      dplyr::summarise(dplyr::across(!!y_var, ~sum(.x, na.rm = TRUE))) %>%
-      dplyr::ungroup()
-    
-    y_var_vctr <- dplyr::pull(data_sum, !!y_var)
+  if (!is.null(position)) {
+    if (position == "stack") {
+      data_sum <- data %>%
+        dplyr::group_by(dplyr::across(!!x_var), .drop = FALSE) %>%
+        dplyr::summarise(dplyr::across(!!y_var, ~sum(.x, na.rm = TRUE))) %>%
+        dplyr::ungroup()
+      
+      y_var_vctr <- dplyr::pull(data_sum, !!y_var)
+    }
+    # else if (position == "fill") y_var_vctr <- c(0, 1)
   }
   
   y_zero_list <- sv_y_zero_adjust(y_var_vctr, y_balance = y_balance, y_zero = y_zero, y_zero_line = y_zero_line)
@@ -579,6 +599,11 @@ gg_bar_col <- function(data,
   
   if(is.null(col_labels)) col_labels <- function(x) stringr::str_to_sentence(x)
   
+  if (y_gridlines_minor == TRUE) {
+    plot <- plot +
+      theme(panel.grid.minor.y = element_line(colour = "#D3D3D3", size = 0.2))
+  }
+  
   plot <- plot +
     scale_fill_manual(
       values = pal,
@@ -626,7 +651,7 @@ gg_bar_col <- function(data,
         fill = guide_legend(ncol = 1, title = stringr::str_wrap(col_title, 20)),
         col = guide_legend(ncol = 1, title = stringr::str_wrap(col_title, 20))
       ) +
-      theme_mobile_graph()
+      theme_mobile_extra()
   }
   
   return(plot)
@@ -649,6 +674,7 @@ gg_bar_col <- function(data,
 #' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 100. 
 #' @param x_balance For a numeric x variable, add balance to the x scale so that zero is in the centre. Defaults to FALSE.
 #' @param x_expand A vector of range expansion constants used to add padding to the x scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
+#' @param y_gridlines_minor TRUE or FALSE of whether to add minor gridlines to the y scale. Defaults to FALSE.
 #' @param x_labels A function or vector to modify x scale labels, as per the ggplot2 labels argument in ggplot2 scales functions. If NULL, categorical variable labels are converted to sentence case. Use ggplot2::waiver() to keep x labels untransformed.
 #' @param x_na TRUE or FALSE of whether to include x_var NA values. Defaults to TRUE.
 #' @param x_pretty_n For a numeric or date x variable, the desired number of intervals on the x scale, as calculated by the pretty algorithm. Defaults to 3. 
@@ -688,7 +714,10 @@ gg_bar_col <- function(data,
 #'   group_by(species, sex) %>% 
 #'   summarise(body_mass_g = mean(body_mass_g, na.rm = TRUE))  
 #' 
-#' gg_bar_facet(plot_data, sex, body_mass_g, species)
+#' gg_bar_facet(plot_data, 
+#'              x_var = sex, 
+#'              y_var = body_mass_g, 
+#'              facet_var = species)
 #'
 gg_bar_facet <- function(data,
                           x_var,
@@ -715,6 +744,7 @@ gg_bar_facet <- function(data,
                           x_zero_line = NULL,
                           y_balance = FALSE,
                           y_expand = NULL,
+                          y_gridlines_minor = FALSE,
                           y_labels = waiver(),
                           y_na = TRUE,
                           y_pretty_n = 4,
@@ -798,7 +828,7 @@ gg_bar_facet <- function(data,
   bar_width <- bar_unit * width
   
   plot <- ggplot(data) +
-    theme_bar(
+    theme_y_gridlines(
       font_family = font_family,
       font_size_body = font_size_body,
       font_size_title = font_size_title
@@ -896,6 +926,11 @@ gg_bar_facet <- function(data,
   
   if(is.null(facet_labels)) facet_labels <- as_labeller(stringr::str_to_sentence)
   
+  if (y_gridlines_minor == TRUE) {
+    plot <- plot +
+      theme(panel.grid.minor.y = element_line(colour = "#D3D3D3", size = 0.2))
+  }
+  
   plot <- plot +
     labs(
       title = stringr::str_wrap(title, title_wrap),
@@ -939,6 +974,7 @@ gg_bar_facet <- function(data,
 #' @param x_zero_line For a numeric x variable, TRUE or FALSE of whether to add a zero reference line to the x scale. Defaults to TRUE if there are positive and negative values in x_var. Otherwise defaults to FALSE.   
 #' @param y_balance For a numeric y variable, add balance to the y scale so that zero is in the centre of the y scale.
 #' @param y_expand A vector of range expansion constants used to add padding to the y scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
+#' @param y_gridlines_minor TRUE or FALSE of whether to add minor gridlines to the y scale. Defaults to FALSE.
 #' @param y_labels A function or vector to modify y scale labels, as per the ggplot2 labels argument in ggplot2 scales functions. If NULL, categorical variable labels are converted to sentence case. Use ggplot2::waiver() to keep y labels untransformed.
 #' @param y_na TRUE or FALSE of whether to include y_var NA values. Defaults to TRUE.
 #' @param y_pretty_n For a numeric or date y variable, the desired number of intervals on the y scale, as calculated by the pretty algorithm. Defaults to 4. 
@@ -975,7 +1011,12 @@ gg_bar_facet <- function(data,
 #'   group_by(species, sex, island) %>% 
 #'   summarise(body_mass_g = mean(body_mass_g, na.rm = TRUE))  
 #' 
-#' gg_bar_col_facet(plot_data, species, body_mass_g, island, sex)
+#' gg_bar_col_facet(plot_data, 
+#'                  x_var = species, 
+#'                  y_var = body_mass_g, 
+#'                  col_var = island, 
+#'                  facet_var = sex, 
+#'                  facet_na = FALSE)
 #' 
 gg_bar_col_facet <- function(data,
                               x_var,
@@ -983,7 +1024,7 @@ gg_bar_col_facet <- function(data,
                               col_var,
                               facet_var,
                               text_var = NULL,
-                              position = "dodge",
+                              position = NULL,
                               pal = NULL,
                               pal_rev = FALSE,
                               width = 0.75,
@@ -1005,6 +1046,7 @@ gg_bar_col_facet <- function(data,
                               x_zero_line = NULL,
                               y_balance = FALSE,
                               y_expand = NULL,
+                              y_gridlines_minor = FALSE,
                               y_labels = waiver(),
                               y_na = TRUE,
                               y_pretty_n = 4,
@@ -1065,13 +1107,6 @@ gg_bar_col_facet <- function(data,
   if (is.numeric(col_var_vctr)) stop("Please use a categorical colour variable for a vertical bar plot")
   if (is.numeric(facet_var_vctr)) stop("Please use a categorical facet variable for a vertical bar plot")
   
-  if (y_trans != "identity") {
-    if (position == "stack") stop("Please use position = 'dodge', if you would like to not have zero as the minimum of y scale")
-  } 
-  if (y_zero == FALSE) {
-    if (position == "stack") stop("Please use position = 'dodge', if you would like to not have zero as the minimum of y scale")
-  } 
-  
   if(is.logical(x_var_vctr)) {
     data <- data %>% 
       dplyr::mutate(dplyr::across(!!x_var, ~factor(., levels = c("TRUE", "FALSE"))))
@@ -1119,9 +1154,6 @@ gg_bar_col_facet <- function(data,
   if(is.null(font_size_title)) font_size_title <- sv_font_size_title(mobile = FALSE)
   if(is.null(font_size_body)) font_size_body <- sv_font_size_body(mobile = FALSE)
   
-  if (position == "stack") position2 <- "stack"
-  else if (position == "dodge") position2 <- position_dodge2(preserve = "single")
-  
   if (lubridate::is.Date(x_var_vctr)) bar_unit <- 365
   else bar_unit <- 1
   
@@ -1137,22 +1169,34 @@ gg_bar_col_facet <- function(data,
   
   if (pal_rev == TRUE) pal <- rev(pal)
   
+  if(!is.null(position)) {
+    if (!position %in% c("dodge", "stack")) stop("Please use a position of either 'stack' or 'fill'")
+  }
+  
+  if (is.null(position)) {
+    position2 <- position_dodge2(preserve = "single")
+  }
+  else position2 <- position
+
   plot <- ggplot(data) +
     coord_cartesian() +
-    theme_bar(font_family = font_family, font_size_body = font_size_body, font_size_title = font_size_title) +
+    theme_y_gridlines(font_family = font_family, font_size_body = font_size_body, font_size_title = font_size_title) +
     geom_col(aes(x = !!x_var, y = !!y_var, col = !!col_var, fill = !!col_var, text = !!text_var), 
              alpha = alpha, 
              size = size_line, 
              width = bar_width, 
              position = position2)
   
-  if (position == "stack") {
-    data_sum <- data %>%
-      dplyr::group_by(dplyr::across(c(!!x_var, !!facet_var)), .drop = FALSE) %>%
-      dplyr::summarise(dplyr::across(!!y_var, ~sum(.x, na.rm = TRUE))) %>%
-      dplyr::ungroup()
-    
-    y_var_vctr <- dplyr::pull(data_sum, !!y_var)
+  if (!is.null(position)) {
+    if (position == "stack") {
+      data_sum <- data %>%
+        dplyr::group_by(dplyr::across(c(!!x_var, !!facet_var)), .drop = FALSE) %>%
+        dplyr::summarise(dplyr::across(!!y_var, ~sum(.x, na.rm = TRUE))) %>%
+        dplyr::ungroup()
+      
+      y_var_vctr <- dplyr::pull(data_sum, !!y_var)
+    }
+    # else if (position == "fill") y_var_vctr <- c(0, 1)
   }
   
   if (facet_scales %in% c("fixed", "free_y")) {
@@ -1247,6 +1291,11 @@ gg_bar_col_facet <- function(data,
   if(is.null(col_labels)) col_labels <- function(x) stringr::str_to_sentence(x)
   if(is.null(facet_labels)) facet_labels <- as_labeller(stringr::str_to_sentence)
   
+  if (y_gridlines_minor == TRUE) {
+    plot <- plot +
+      theme(panel.grid.minor.y = element_line(colour = "#D3D3D3", size = 0.2))
+  }
+  
   plot <- plot +
     scale_fill_manual(
       values = pal,
