@@ -23,7 +23,9 @@
 #' @return A ggplot object.
 #' @export
 #' @examples
-#' gg_sf(example_sf_point, borders = nz)
+#' gg_sf(example_sf_point, 
+#'      borders = nz)
+#'      
 gg_sf <- function(data,
                   text_var = NULL,
                   size_point = 1,
@@ -56,7 +58,7 @@ gg_sf <- function(data,
   if(is.null(font_size_body)) font_size_body <- sv_font_size_body(mobile = mobile)
   
   plot <- ggplot(data) +
-    theme_sf(
+    theme_map(
       font_family = font_family,
       font_size_body = font_size_body,
       font_size_title = font_size_title
@@ -123,7 +125,7 @@ gg_sf <- function(data,
         subtitle = stringr::str_wrap(subtitle, 40),
         caption = stringr::str_wrap(caption, 50)
       ) + 
-      theme_mobile_map()
+      theme_mobile_extra_map()
   }
   
   return(plot)
@@ -165,14 +167,22 @@ gg_sf <- function(data,
 #' @return A ggplot object.
 #' @export
 #' @examples
-#' gg_sf_col(example_sf_point, trend_category, 
+#' gg_sf_col(example_sf_point, 
+#'           col_var = trend_category, 
 #'           borders = nz)
 #'    
-#' gg_sf_col(example_sf_polygon, density, 
-#'      borders = nz, col_method = "bin", col_cuts = c(0, 10, 50, 100, 150, 200, Inf))
+#' gg_sf_col(example_sf_polygon, 
+#'           col_var = density, 
+#'           borders = nz, 
+#'           col_method = "bin", 
+#'           col_cuts = c(0, 10, 50, 100, 150, 200, Inf))
 #'
-#' gg_sf_col(example_sf_polygon, density, borders = nz,
-#'      col_method = "quantile", col_cuts = c(0, 0.25, 0.5, 0.75, 0.95, 1))
+#' gg_sf_col(example_sf_polygon, 
+#'           col_var = density, 
+#'           borders = nz, 
+#'           col_method = "quantile", 
+#'           col_cuts = c(0, 0.25, 0.5, 0.75, 0.95, 1))
+#'           
 gg_sf_col <- function(data,
                       col_var,
                       text_var = NULL,
@@ -235,7 +245,7 @@ gg_sf_col <- function(data,
   geometry_type <- unique(sf::st_geometry_type(data))
   
   plot <- ggplot(data) +
-    theme_sf(
+    theme_map(
       font_family = font_family,
       font_size_body = font_size_body,
       font_size_title = font_size_title
@@ -377,7 +387,7 @@ gg_sf_col <- function(data,
       )  +
       guides(col = guide_legend(ncol = 1, byrow = TRUE, title = stringr::str_wrap(col_title, 20))) +
       guides(col = guide_legend(ncol = 1, byrow = TRUE, title = stringr::str_wrap(col_title, 20))) +
-      theme_mobile_map()
+      theme_mobile_extra_map()
   }
   
   return(plot)
@@ -412,7 +422,10 @@ gg_sf_col <- function(data,
 #' @return A ggplot object.
 #' @export
 #' @examples
-#' gg_sf_facet(example_sf_point, trend_category, borders = nz)
+#' gg_sf_facet(example_sf_point, 
+#'             facet_var = trend_category, 
+#'             borders = nz)
+#' 
 gg_sf_facet <- function(data,
                         facet_var,
                         text_var = NULL,
@@ -468,7 +481,7 @@ gg_sf_facet <- function(data,
   geometry_type <- unique(sf::st_geometry_type(data))
   
   plot <- ggplot(data) +
-    theme_sf(
+    theme_map(
       font_family = font_family,
       font_size_body = font_size_body,
       font_size_title = font_size_title
@@ -585,8 +598,10 @@ gg_sf_facet <- function(data,
 #' @return A ggplot object.
 #' @export
 #' @examples
-#' gg_sf_col_facet(example_sf_point, trend_category, trend_category,
-#'  borders = nz)
+#' gg_sf_col_facet(example_sf_point, 
+#'                 col_var = trend_category, 
+#'                 facet_var = trend_category, 
+#'                 borders = nz)
 #'  
 gg_sf_col_facet <- function(data,
                             col_var,
@@ -667,7 +682,7 @@ gg_sf_col_facet <- function(data,
   geometry_type <- unique(sf::st_geometry_type(data))
   
   plot <- ggplot(data) +
-    theme_sf(
+    theme_map(
       font_family = font_family,
       font_size_body = font_size_body,
       font_size_title = font_size_title
