@@ -1,4 +1,4 @@
-#' @title Theme for box ggplots.
+#' @title Theme for graphs with horizontal y gridlines.
 #' @param font_family Font family to use. Defaults to "".
 #' @param font_size_title Font size for the title text. Defaults to 11.
 #' @param font_size_body Font size for all text other than the title. Defaults to 10.
@@ -6,541 +6,11 @@
 #' @export
 #' @examples
 #' library(ggplot2)
-#' 
+#'
 #' ggplot() +
-#'   theme_boxplot("Courier", 9, 7) +
+#'   theme_y_gridlines("Courier", 9, 7) +
 #'   ggtitle("This is a title of a font family and size")
-theme_boxplot <-
-  function(font_family = "",
-           font_size_title = 11,
-           font_size_body = 10) {
-    list(
-      theme(
-        plot.title = element_text(
-          family = font_family,
-          colour = "#000000",
-          size = font_size_title,
-          face = "bold",
-          hjust = 0.5
-        ),
-        plot.subtitle = element_text(
-          family = font_family,
-          colour = "#000000",
-          size = font_size_body,
-          face = "plain",
-          hjust = 0.5
-        ),
-        plot.caption = element_text(
-          family = font_family,
-          colour = "#323232",
-          size = font_size_body,
-          face = "plain",
-          hjust = 0.99
-        ),
-        plot.margin = margin(
-          t = 5,
-          l = 5,
-          b = 5,
-          r = 20
-        ),
-        panel.border = element_blank(),
-        panel.spacing = unit(2.5, "lines"),
-        panel.grid.major.x = element_blank(),
-        panel.grid.minor.x = element_blank(),
-        panel.grid.major.y = element_line(colour = "#D3D3D3", size = 0.2),
-        panel.grid.minor.y = element_blank(),
-        panel.background = element_rect(colour = "white", fill = "white"),
-        strip.background = element_rect(colour = "white", fill = "white"),
-        text = element_text(
-          family = font_family,
-          colour = "#323232",
-          size = font_size_body
-        ),
-        strip.text = element_text(
-          family = font_family,
-          colour = "#323232",
-          size = font_size_body,
-          hjust = 0.5
-        ),
-        axis.title.x = element_text(
-          family = font_family,
-          colour = "#323232",
-          size = font_size_body,
-          margin = margin(t = 10)
-        ),
-        axis.title.y = element_text(
-          family = font_family,
-          colour = "#323232",
-          size = font_size_body,
-          margin = margin(r = 10)
-        ),
-        axis.text.x = element_text(
-          family = font_family,
-          colour = "#323232",
-          size = font_size_body
-        ),
-        axis.text.y = element_text(
-          family = font_family,
-          colour = "#323232",
-          hjust = 1,
-          size = font_size_body
-        ),
-        axis.line = element_line(colour = "#323232", size = 0.3),
-        axis.ticks = element_line(colour = "#323232", size = 0.3),
-        legend.text = element_text(
-          family = font_family,
-          colour = "#323232",
-          size = font_size_body,
-          margin = margin(r = 10),
-          hjust = 0
-        ),
-        legend.title = element_text(
-          family = font_family,
-          colour = "#323232",
-          size = font_size_body,
-          margin = margin(r = 20)
-        ),
-        legend.margin = margin(t = 20, b = 20),
-        legend.key = element_rect(fill = "white"),
-        legend.key.height = unit(5, "mm"),
-        legend.key.width = unit(5, "mm"),
-        legend.direction = "vertical" 
-      )
-    )
-  }
-
-#' @title Theme for horizontal bar ggplots.
-#' @param font_family Font family to use. Defaults to "".
-#' @param font_size_title Font size for the title text. Defaults to 11.
-#' @param font_size_body Font size for all text other than the title. Defaults to 10.
-#' @return A ggplot theme.
-#' @export
-#' @examples
-#' library(ggplot2)
-#' 
-#' ggplot() +
-#'   theme_hbar("Courier", 9, 7) +
-#'   ggtitle("This is a title of a font family and size")
-theme_hbar <-
-  function(font_family = "",
-           font_size_title = 11,
-           font_size_body = 10) {
-    list(
-      theme(
-        plot.title = element_text(
-          family = font_family,
-          colour = "#000000",
-          size = font_size_title,
-          face = "bold",
-          hjust = 0.5
-        ),
-        plot.subtitle = element_text(
-          family = font_family,
-          colour = "#000000",
-          size = font_size_body,
-          face = "plain",
-          hjust = 0.5
-        ),
-        plot.caption = element_text(
-          family = font_family,
-          colour = "#323232",
-          size = font_size_body,
-          face = "plain",
-          hjust = 0.99
-        ),
-        plot.margin = margin(
-          t = 5,
-          l = 5,
-          b = 5,
-          r = 20
-        ),
-        panel.border = element_blank(),
-        panel.spacing = unit(2.5, "lines"),
-        panel.grid.major.x = element_line(colour = "#D3D3D3", size = 0.2),
-        panel.grid.minor.x = element_blank(),
-        panel.grid.major.y = element_blank(),
-        panel.grid.minor.y = element_blank(),
-        panel.background = element_rect(colour = "white", fill = "white"),
-        strip.background = element_rect(colour = "white", fill = "white"),
-        text = element_text(
-          family = font_family,
-          colour = "#323232",
-          size = font_size_body
-        ),
-        strip.text = element_text(
-          family = font_family,
-          colour = "#323232",
-          size = font_size_body,
-          hjust = 0.5
-        ),
-        axis.title.x = element_text(
-          family = font_family,
-          colour = "#323232",
-          size = font_size_body,
-          margin = margin(t = 10)
-        ),
-        axis.title.y = element_text(
-          family = font_family,
-          colour = "#323232",
-          size = font_size_body,
-          margin = margin(r = 10)
-        ),
-        axis.text.x = element_text(
-          family = font_family,
-          colour = "#323232",
-          size = font_size_body
-        ),
-        axis.text.y = element_text(
-          family = font_family,
-          colour = "#323232",
-          hjust = 1,
-          size = font_size_body
-        ),
-        axis.line = element_line(colour = "#323232", size = 0.3),
-        axis.ticks = element_line(colour = "#323232", size = 0.3),
-        legend.text = element_text(
-          family = font_family,
-          colour = "#323232",
-          size = font_size_body,
-          margin = margin(r = 10),
-          hjust = 0
-        ),
-        legend.title = element_text(
-          family = font_family,
-          colour = "#323232",
-          size = font_size_body,
-          margin = margin(r = 20)
-        ),
-        legend.margin = margin(t = 20, b = 20),
-        legend.key.height = unit(5, "mm"),
-        legend.key.width = unit(5, "mm"),
-        legend.direction = "vertical" 
-      )
-    )
-  }
-
-#' @title Theme for line ggplots.
-#' @param font_family Font family to use. Defaults to "".
-#' @param font_size_title Font size for the title text. Defaults to 11.
-#' @param font_size_body Font size for all text other than the title. Defaults to 10.
-#' @return A ggplot theme.
-#' @export
-#' @examples
-#' library(ggplot2)
-#' 
-#' ggplot() +
-#'   theme_line("Courier", 9, 7) +
-#'   ggtitle("This is a title of a font family and size")
-theme_line <-
-  function(font_family = "",
-           font_size_title = 11,
-           font_size_body = 10) {
-    list(
-      theme(
-        plot.title = element_text(
-          family = font_family,
-          colour = "#000000",
-          size = font_size_title,
-          face = "bold",
-          hjust = 0.5
-        ),
-        plot.subtitle = element_text(
-          family = font_family,
-          colour = "#000000",
-          size = font_size_body,
-          face = "plain",
-          hjust = 0.5
-        ),
-        plot.caption = element_text(
-          family = font_family,
-          colour = "#323232",
-          size = font_size_body,
-          face = "plain",
-          hjust = 0.99
-        ),
-        plot.margin = margin(
-          t = 5,
-          l = 5,
-          b = 5,
-          r = 20
-        ),
-        panel.border = element_blank(),
-        panel.spacing = unit(2.5, "lines"),
-        panel.grid.major.x = element_blank(),
-        panel.grid.minor.x = element_blank(),
-        panel.grid.major.y = element_line(colour = "#D3D3D3", size = 0.2),
-        panel.grid.minor.y = element_blank(),
-        panel.background = element_rect(colour = "white", fill = "white"),
-        strip.background = element_rect(colour = "white", fill = "white"),
-        text = element_text(
-          family = font_family,
-          colour = "#323232",
-          size = font_size_body
-        ),
-        strip.text = element_text(
-          family = font_family,
-          colour = "#323232",
-          size = font_size_body
-        ),
-        axis.title.x = element_text(
-          family = font_family,
-          colour = "#323232",
-          size = font_size_body,
-          margin = margin(t = 10)
-        ),
-        axis.title.y = element_text(
-          family = font_family,
-          colour = "#323232",
-          size = font_size_body,
-          margin = margin(r = 10)
-        ),
-        axis.text.x = element_text(
-          family = font_family,
-          colour = "#323232",
-          size = font_size_body
-        ),
-        axis.text.y = element_text(
-          family = font_family,
-          colour = "#323232",
-          hjust = 1,
-          size = font_size_body
-        ),
-        axis.line = element_line(colour = "#323232", size = 0.3),
-        axis.ticks = element_line(colour = "#323232", size = 0.3),
-        legend.text = element_text(
-          family = font_family,
-          colour = "#323232",
-          size = font_size_body,
-          margin = margin(r = 10),
-          hjust = 0
-        ),
-        legend.title = element_text(
-          family = font_family,
-          colour = "#323232",
-          size = font_size_body,
-          margin = margin(r = 20)
-        ),
-        legend.margin = margin(t = 20, b = 20),
-        legend.key = element_rect(fill = "white"),
-        legend.key.height = unit(5, "mm"),
-        legend.key.width = unit(5, "mm"),
-        legend.direction = "vertical" 
-      )
-    )
-  }
-#' @title Theme for point ggplots.
-#' @param font_family Font family to use. Defaults to "".
-#' @param font_size_title Font size for the title text. Defaults to 11.
-#' @param font_size_body Font size for all text other than the title. Defaults to 10.
-#' @return A ggplot theme.
-#' @export
-#' @examples
-#' library(ggplot2)
-#' 
-#' ggplot() +
-#'   theme_point("Courier", 9, 7) +
-#'   ggtitle("This is a title of a font family and size")
-theme_point <-
-  function(font_family = "",
-           font_size_title = 11,
-           font_size_body = 10) {
-    list(
-      theme(
-        plot.title = element_text(
-          family = font_family,
-          colour = "#000000",
-          size = font_size_title,
-          face = "bold",
-          hjust = 0.5
-        ),
-        plot.subtitle = element_text(
-          family = font_family,
-          colour = "#000000",
-          size = font_size_body,
-          face = "plain",
-          hjust = 0.5
-        ),
-        plot.caption = element_text(
-          family = font_family,
-          colour = "#323232",
-          size = font_size_body,
-          face = "plain",
-          hjust = 0.99
-        ),
-        plot.margin = margin(
-          t = 5,
-          l = 5,
-          b = 5,
-          r = 20
-        ),
-        panel.border = element_blank(),
-        panel.spacing = unit(2.5, "lines"),
-        panel.grid.major.x = element_line(colour = "#D3D3D3", size = 0.2),
-        panel.grid.minor.x = element_blank(),
-        panel.grid.major.y = element_line(colour = "#D3D3D3", size = 0.2),
-        panel.grid.minor.y = element_blank(),
-        panel.background = element_rect(colour = "white", fill = "white"),
-        strip.background = element_rect(colour = "white", fill = "white"),
-        text = element_text(
-          family = font_family,
-          colour = "#323232",
-          size = font_size_body
-        ),
-        strip.text = element_text(
-          family = font_family,
-          colour = "#323232",
-          size = font_size_body
-        ),
-        axis.title.x = element_text(
-          family = font_family,
-          colour = "#323232",
-          size = font_size_body,
-          margin = margin(t = 10)
-        ),
-        axis.title.y = element_text(
-          family = font_family,
-          colour = "#323232",
-          size = font_size_body,
-          margin = margin(r = 10)
-        ),
-        axis.text.x = element_text(
-          family = font_family,
-          colour = "#323232",
-          size = font_size_body
-        ),
-        axis.text.y = element_text(
-          family = font_family,
-          colour = "#323232",
-          hjust = 1,
-          size = font_size_body
-        ),
-        axis.line = element_line(colour = "#323232", size = 0.3),
-        axis.ticks = element_line(colour = "#323232", size = 0.3),
-        legend.text = element_text(
-          family = font_family,
-          colour = "#323232",
-          size = font_size_body,
-          margin = margin(r = 10),
-          hjust = 0
-        ),
-        legend.title = element_text(
-          family = font_family,
-          colour = "#323232",
-          size = font_size_body,
-          margin = margin(r = 20)
-        ),
-        legend.margin = margin(t = 20, b = 20),
-        legend.key = element_rect(fill = "white"),
-        legend.key.height = unit(5, "mm"),
-        legend.key.width = unit(5, "mm"),
-        legend.direction = "vertical" 
-      )
-    )
-  }
-
-#' @title Theme for ggplot maps of simple features.
-#' @param font_family Font family to use. Defaults to "".
-#' @param font_size_title Font size for the title text. Defaults to 11.
-#' @param font_size_body Font size for all text other than the title. Defaults to 10.
-#' @return A ggplot theme.
-#' @export
-#' @examples
-#' library(ggplot2)
-#' 
-#' ggplot() +
-#'   theme_sf("Courier", 9, 7) +
-#'   ggtitle("This is a title of a font family and size")
-theme_sf <-
-  function(font_family = "",
-           font_size_title = 11,
-           font_size_body = 10) {
-    list(
-      theme(
-        plot.title = element_text(
-          family = font_family,
-          colour = "#000000",
-          size = font_size_title,
-          face = "bold",
-          hjust = 0.5
-        ),
-        plot.subtitle = element_text(
-          family = font_family,
-          colour = "#000000",
-          size = font_size_body,
-          face = "plain",
-          hjust = 0.5
-        ),
-        plot.caption = element_text(
-          family = font_family,
-          colour = "#323232",
-          size = font_size_body,
-          face = "plain",
-          hjust = 0.99
-        ),
-        plot.margin = margin(
-          t = 5,
-          l = 5,
-          b = 5,
-          r = 20
-        ),
-        panel.border = element_blank(),
-        panel.spacing = unit(2.5, "lines"),
-        panel.grid.major.x = element_blank(),
-        panel.grid.minor.x = element_blank(),
-        panel.grid.major.y = element_blank(),
-        panel.grid.minor.y = element_blank(),
-        panel.background = element_rect(colour = "white", fill = "white"),
-        strip.background = element_rect(colour = "white", fill = "white"),
-        text = element_text(
-          family = font_family,
-          colour = "#323232",
-          size = font_size_body
-        ),
-        strip.text = element_text(
-          family = font_family,
-          colour = "#323232",
-          size = font_size_body
-        ),
-        axis.title.x = element_blank(),
-        axis.title.y = element_blank(),
-        axis.text.x = element_blank(),
-        axis.text.y = element_blank(),
-        axis.line = element_blank(),
-        axis.ticks = element_blank(),
-        legend.text = element_text(
-          family = font_family,
-          colour = "#323232",
-          size = font_size_body,
-          margin = margin(r = 10),
-          hjust = 0
-        ),
-        legend.title = element_text(
-          family = font_family,
-          colour = "#323232",
-          size = font_size_body,
-          margin = margin(r = 20)
-        ),
-        legend.key = element_rect(fill = "white"),
-        legend.key.height = unit(5, "mm"),
-        legend.key.width = unit(5, "mm"),
-        legend.direction = "vertical" 
-      )
-    )
-  }
-
-#' @title Theme for vertical bar ggplots.
-#' @param font_family Font family to use. Defaults to "".
-#' @param font_size_title Font size for the title text. Defaults to 11.
-#' @param font_size_body Font size for all text other than the title. Defaults to 10.
-#' @return A ggplot theme.
-#' @export
-#' @examples
-#' library(ggplot2)
-#' 
-#' ggplot() +
-#'   theme_bar("Courier", 9, 7) +
-#'   ggtitle("This is a title of a font family and size")
-theme_bar <-
+theme_y_gridlines <-
   function(font_family = "",
            font_size_title = 11,
            font_size_body = 10) {
@@ -631,9 +101,321 @@ theme_bar <-
           margin = margin(r = 20)
         ),
         legend.margin = margin(t = 20, b = 20),
+        legend.key = element_rect(fill = "white"),
         legend.key.height = unit(5, "mm"),
         legend.key.width = unit(5, "mm"),
-        legend.direction = "vertical" 
+        legend.direction = "vertical"
+      )
+    )
+  }
+
+#' @title Theme for graphs with vertical x gridlines.
+#' @param font_family Font family to use. Defaults to "".
+#' @param font_size_title Font size for the title text. Defaults to 11.
+#' @param font_size_body Font size for all text other than the title. Defaults to 10.
+#' @return A ggplot theme.
+#' @export
+#' @examples
+#' library(ggplot2)
+#'
+#' ggplot() +
+#'   theme_x_gridlines("Courier", 9, 7) +
+#'   ggtitle("This is a title of a font family and size")
+theme_x_gridlines <-
+  function(font_family = "",
+           font_size_title = 11,
+           font_size_body = 10) {
+    list(
+      theme(
+        plot.title = element_text(
+          family = font_family,
+          colour = "#000000",
+          size = font_size_title,
+          face = "bold",
+          hjust = 0.5
+        ),
+        plot.subtitle = element_text(
+          family = font_family,
+          colour = "#000000",
+          size = font_size_body,
+          face = "plain",
+          hjust = 0.5
+        ),
+        plot.caption = element_text(
+          family = font_family,
+          colour = "#323232",
+          size = font_size_body,
+          face = "plain",
+          hjust = 0.99
+        ),
+        plot.margin = margin(
+          t = 5,
+          l = 5,
+          b = 5,
+          r = 20
+        ),
+        panel.border = element_blank(),
+        panel.spacing = unit(2.5, "lines"),
+        panel.grid.major.x = element_line(colour = "#D3D3D3", size = 0.2),
+        panel.grid.minor.x = element_blank(),
+        panel.grid.major.y = element_blank(),
+        panel.grid.minor.y = element_blank(),
+        panel.background = element_rect(colour = "white", fill = "white"),
+        strip.background = element_rect(colour = "white", fill = "white"),
+        text = element_text(
+          family = font_family,
+          colour = "#323232",
+          size = font_size_body
+        ),
+        strip.text = element_text(
+          family = font_family,
+          colour = "#323232",
+          size = font_size_body,
+          hjust = 0.5
+        ),
+        axis.title.x = element_text(
+          family = font_family,
+          colour = "#323232",
+          size = font_size_body,
+          margin = margin(t = 10)
+        ),
+        axis.title.y = element_text(
+          family = font_family,
+          colour = "#323232",
+          size = font_size_body,
+          margin = margin(r = 10)
+        ),
+        axis.text.x = element_text(
+          family = font_family,
+          colour = "#323232",
+          size = font_size_body
+        ),
+        axis.text.y = element_text(
+          family = font_family,
+          colour = "#323232",
+          hjust = 1,
+          size = font_size_body
+        ),
+        axis.line = element_line(colour = "#323232", size = 0.3),
+        axis.ticks = element_line(colour = "#323232", size = 0.3),
+        legend.text = element_text(
+          family = font_family,
+          colour = "#323232",
+          size = font_size_body,
+          margin = margin(r = 10),
+          hjust = 0
+        ),
+        legend.title = element_text(
+          family = font_family,
+          colour = "#323232",
+          size = font_size_body,
+          margin = margin(r = 20)
+        ),
+        legend.margin = margin(t = 20, b = 20),
+        legend.key = element_rect(fill = "white"),
+        legend.key.height = unit(5, "mm"),
+        legend.key.width = unit(5, "mm"),
+        legend.direction = "vertical"
+      )
+    )
+  }
+
+#' @title Theme for graphs with x and y gridlines.
+#' @param font_family Font family to use. Defaults to "".
+#' @param font_size_title Font size for the title text. Defaults to 11.
+#' @param font_size_body Font size for all text other than the title. Defaults to 10.
+#' @return A ggplot theme.
+#' @export
+#' @examples
+#' library(ggplot2)
+#'
+#' ggplot() +
+#'   theme_xy_gridlines("Courier", 9, 7) +
+#'   ggtitle("This is a title of a font family and size")
+theme_xy_gridlines <-
+  function(font_family = "",
+           font_size_title = 11,
+           font_size_body = 10) {
+    list(
+      theme(
+        plot.title = element_text(
+          family = font_family,
+          colour = "#000000",
+          size = font_size_title,
+          face = "bold",
+          hjust = 0.5
+        ),
+        plot.subtitle = element_text(
+          family = font_family,
+          colour = "#000000",
+          size = font_size_body,
+          face = "plain",
+          hjust = 0.5
+        ),
+        plot.caption = element_text(
+          family = font_family,
+          colour = "#323232",
+          size = font_size_body,
+          face = "plain",
+          hjust = 0.99
+        ),
+        plot.margin = margin(
+          t = 5,
+          l = 5,
+          b = 5,
+          r = 20
+        ),
+        panel.border = element_blank(),
+        panel.spacing = unit(2.5, "lines"),
+        panel.grid.major.x = element_line(colour = "#D3D3D3", size = 0.2),
+        panel.grid.minor.x = element_blank(),
+        panel.grid.major.y = element_line(colour = "#D3D3D3", size = 0.2),
+        panel.grid.minor.y = element_blank(),
+        panel.background = element_rect(colour = "white", fill = "white"),
+        strip.background = element_rect(colour = "white", fill = "white"),
+        text = element_text(
+          family = font_family,
+          colour = "#323232",
+          size = font_size_body
+        ),
+        strip.text = element_text(
+          family = font_family,
+          colour = "#323232",
+          size = font_size_body
+        ),
+        axis.title.x = element_text(
+          family = font_family,
+          colour = "#323232",
+          size = font_size_body,
+          margin = margin(t = 10)
+        ),
+        axis.title.y = element_text(
+          family = font_family,
+          colour = "#323232",
+          size = font_size_body,
+          margin = margin(r = 10)
+        ),
+        axis.text.x = element_text(
+          family = font_family,
+          colour = "#323232",
+          size = font_size_body
+        ),
+        axis.text.y = element_text(
+          family = font_family,
+          colour = "#323232",
+          hjust = 1,
+          size = font_size_body
+        ),
+        axis.line = element_line(colour = "#323232", size = 0.3),
+        axis.ticks = element_line(colour = "#323232", size = 0.3),
+        legend.text = element_text(
+          family = font_family,
+          colour = "#323232",
+          size = font_size_body,
+          margin = margin(r = 10),
+          hjust = 0
+        ),
+        legend.title = element_text(
+          family = font_family,
+          colour = "#323232",
+          size = font_size_body,
+          margin = margin(r = 20)
+        ),
+        legend.margin = margin(t = 20, b = 20),
+        legend.key = element_rect(fill = "white"),
+        legend.key.height = unit(5, "mm"),
+        legend.key.width = unit(5, "mm"),
+        legend.direction = "vertical"
+      )
+    )
+  }
+
+#' @title Theme for maps.
+#' @param font_family Font family to use. Defaults to "".
+#' @param font_size_title Font size for the title text. Defaults to 11.
+#' @param font_size_body Font size for all text other than the title. Defaults to 10.
+#' @return A ggplot theme.
+#' @export
+#' @examples
+#' library(ggplot2)
+#'
+#' ggplot() +
+#'   theme_map("Courier", 9, 7) +
+#'   ggtitle("This is a title of a font family and size")
+theme_map <-
+  function(font_family = "",
+           font_size_title = 11,
+           font_size_body = 10) {
+    list(
+      theme(
+        plot.title = element_text(
+          family = font_family,
+          colour = "#000000",
+          size = font_size_title,
+          face = "bold",
+          hjust = 0.5
+        ),
+        plot.subtitle = element_text(
+          family = font_family,
+          colour = "#000000",
+          size = font_size_body,
+          face = "plain",
+          hjust = 0.5
+        ),
+        plot.caption = element_text(
+          family = font_family,
+          colour = "#323232",
+          size = font_size_body,
+          face = "plain",
+          hjust = 0.99
+        ),
+        plot.margin = margin(
+          t = 5,
+          l = 5,
+          b = 5,
+          r = 20
+        ),
+        panel.border = element_blank(),
+        panel.spacing = unit(2.5, "lines"),
+        panel.grid.major.x = element_blank(),
+        panel.grid.minor.x = element_blank(),
+        panel.grid.major.y = element_blank(),
+        panel.grid.minor.y = element_blank(),
+        panel.background = element_rect(colour = "white", fill = "white"),
+        strip.background = element_rect(colour = "white", fill = "white"),
+        text = element_text(
+          family = font_family,
+          colour = "#323232",
+          size = font_size_body
+        ),
+        strip.text = element_text(
+          family = font_family,
+          colour = "#323232",
+          size = font_size_body
+        ),
+        axis.title.x = element_blank(),
+        axis.title.y = element_blank(),
+        axis.text.x = element_blank(),
+        axis.text.y = element_blank(),
+        axis.line = element_blank(),
+        axis.ticks = element_blank(),
+        legend.text = element_text(
+          family = font_family,
+          colour = "#323232",
+          size = font_size_body,
+          margin = margin(r = 10),
+          hjust = 0
+        ),
+        legend.title = element_text(
+          family = font_family,
+          colour = "#323232",
+          size = font_size_body,
+          margin = margin(r = 20)
+        ),
+        legend.key = element_rect(fill = "white"),
+        legend.key.height = unit(5, "mm"),
+        legend.key.width = unit(5, "mm"),
+        legend.direction = "vertical"
       )
     )
   }
@@ -643,7 +425,7 @@ theme_bar <-
 #'
 #' @return A ggplot theme.
 #' @keywords internal
-theme_mobile_graph <- function() {
+theme_mobile_extra <- function() {
   theme(
     plot.title.position = "plot",
     plot.caption.position = "plot",
@@ -651,8 +433,8 @@ theme_mobile_graph <- function() {
     legend.position = "bottom",
     legend.justification = "left",
     legend.margin = margin(t = 0, b = 0, l = 0, r = 0),
-    axis.text.x = element_text(hjust = 0.75) 
-  ) 
+    axis.text.x = element_text(hjust = 0.75)
+  )
 }
 
 #' @title Extra theme elements for ggplot2 maps on mobile devices
@@ -660,7 +442,7 @@ theme_mobile_graph <- function() {
 #'
 #' @return A ggplot theme.
 #' @keywords internal
-theme_mobile_map <- function() {
+theme_mobile_extra_map <- function() {
   theme(
     plot.title.position = "plot",
     plot.caption.position = "plot",
@@ -668,5 +450,5 @@ theme_mobile_map <- function() {
     legend.position = "bottom",
     legend.justification = "left",
     legend.margin = margin(t = 0, b = 0, l = 0, r = 0)
-  ) 
-}
+  )
+}
\ No newline at end of file
